==> ldap-account-manager_5.2.orig.tar.bz2: ldap-account-manager-5.2/templates/lib/extra/ckeditor/plugins/link/lang/sv.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'sv', {
	acccessKey: 'Behörighetsnyckel',
	advanced: 'Avancerad',
	advisoryContentType: 'Innehållstyp',
	advisoryTitle: 'Titel',
	anchor: {
		toolbar: 'Infoga/Redigera ankarlänk',
		menu: 'Egenskaper för ankarlänk',
		title: 'Egenskaper för ankarlänk',
		name: 'Ankarnamn',
		errorName: 'Var god ange ett ankarnamn',
		remove: 'Radera ankare'
	},
	anchorId: 'Efter element-id',
	anchorName: 'Efter ankarnamn',
	charset: 'Teckenuppställning',
	cssClasses: 'Stilmall',
	emailAddress: 'E-postadress',
	emailBody: 'Innehåll',
	emailSubject: 'Ämne',
	id: 'Id',
	info: 'Länkinformation',
	langCode: 'Språkkod',
	langDir: 'Språkriktning',
	langDirLTR: 'Vänster till höger (VTH)',
	langDirRTL: 'Höger till vänster (HTV)',
	menu: 'Redigera länk',
	name: 'Namn',
	noAnchors: '(Inga ankare kunde hittas)',
	noEmail: 'Var god ange e-postadress',
	noUrl: 'Var god ange länkens URL',
	other: '<annan>',
	popupDependent: 'Beroende (endast Netscape)',
	popupFeatures: 'Popup-fönstrets egenskaper',
	popupFullScreen: 'Helskärm (endast IE)',
	popupLeft: 'Position från vänster',
	popupLocationBar: 'Adressfält',
	popupMenuBar: 'Menyfält',
	popupResizable: 'Resizable',
	popupScrollBars: 'Scrolllista',
	popupStatusBar: 'Statusfält',
	popupToolbar: 'Verktygsfält',
	popupTop: 'Position från sidans topp',
	rel: 'Förhållande',
	selectAnchor: 'Välj ett ankare',
	styles: 'Stilmall',
	tabIndex: 'Tabindex',
	target: 'Mål',
	targetFrame: '<ram>',
	targetFrameName: 'Målets ramnamn',
	targetPopup: '<popup-fönster>',
	targetPopupName: 'Popup-fönstrets namn',
	title: 'Länk',
	toAnchor: 'Länk till ankare i texten',
	toEmail: 'E-post',
	toUrl: 'URL',
	toolbar: 'Infoga/Redigera länk',
	type: 'Länktyp',
	unlink: 'Radera länk',
	upload: 'Ladda upp'
} );

==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/link/lang/sv.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'sv', {
	acccessKey: 'Behörighetsnyckel',
	advanced: 'Avancerad',
	advisoryContentType: 'Innehållstyp',
	advisoryTitle: 'Titel',
	anchor: {
		toolbar: 'Infoga/Redigera ankarlänk',
		menu: 'Egenskaper för ankarlänk',
		title: 'Egenskaper för ankarlänk',
		name: 'Ankarnamn',
		errorName: 'Var god ange ett ankarnamn',
		remove: 'Radera ankare'
	},
	anchorId: 'Efter element-id',
	anchorName: 'Efter ankarnamn',
	charset: 'Teckenuppställning',
	cssClasses: 'Stilmall',
	download: 'Tvinga nerladdning',
	displayText: 'Visningstext',
	emailAddress: 'E-postadress',
	emailBody: 'Innehåll',
	emailSubject: 'Ämne',
	id: 'Id',
	info: 'Länkinformation',
	langCode: 'Språkkod',
	langDir: 'Språkriktning',
	langDirLTR: 'Vänster till höger (VTH)',
	langDirRTL: 'Höger till vänster (HTV)',
	menu: 'Redigera länk',
	name: 'Namn',
	noAnchors: '(Inga ankare kunde hittas)',
	noEmail: 'Var god ange e-postadress',
	noUrl: 'Var god ange länkens URL',
	other: '<annan>',
	popupDependent: 'Beroende (endast Netscape)',
	popupFeatures: 'Popup-fönstrets egenskaper',
	popupFullScreen: 'Helskärm (endast IE)',
	popupLeft: 'Position från vänster',
	popupLocationBar: 'Adressfält',
	popupMenuBar: 'Menyfält',
	popupResizable: 'Skalbart',
	popupScrollBars: 'Scrolllista',
	popupStatusBar: 'Statusfält',
	popupToolbar: 'Verktygsfält',
	popupTop: 'Position från sidans topp',
	rel: 'Förhållande',
	selectAnchor: 'Välj ett ankare',
	styles: 'Stilmall',
	tabIndex: 'Tabindex',
	target: 'Mål',
	targetFrame: '<ram>',
	targetFrameName: 'Målets ramnamn',
	targetPopup: '<popup-fönster>',
	targetPopupName: 'Popup-fönstrets namn',
	title: 'Länk',
	toAnchor: 'Länk till ankare i texten',
	toEmail: 'E-post',
	toUrl: 'URL',
	toolbar: 'Infoga/Redigera länk',
	type: 'Länktyp',
	unlink: 'Radera länk',
	upload: 'Ladda upp'
} );
